%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%bcond_with mozjs

%define major 1
%define libname		%mklibname proxy %{major}
%define develname	%mklibname -d proxy
%define gnomename	%mklibname proxy-gnome
%define kdename		%mklibname proxy-kde
%define nmname		%mklibname proxy-networkmanager
%define mozjsname	%mklibname proxy-mozjs
%define webkitname	%mklibname proxy-webkit
%define first_biarch_version	0.4.7-2
%define _libexecdir	%{_prefix}/lib

Name:           libproxy
Version:        0.4.17
Release:        %mkrel 2
Summary:        A library handling all the details of proxy configuration

Group:          System/Libraries
License:        LGPLv2+
URL:            https://libproxy.github.io/libproxy/
Source0:        https://github.com/libproxy/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        proxy.1
Patch1:		disable-pac-test.patch
Patch3:		perl-binding-datatype.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(python3)
#perl
BuildRequires:  perl-devel
%if !%{bootstrap}
%if %{with mozjs}
# mozjs
BuildRequires:  pkgconfig(mozjs185)
%endif
# NetworkManager
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(dbus-glib-1)
# gnome3
BuildRequires:	glib2-devel >= 2.26
# webkit (gtk)
BuildRequires:  pkgconfig(javascriptcoregtk-4.0)

BuildRequires:  pkgconfig(xmu)
%endif


%description
libproxy offers the following features:

    * extremely small core footprint (< 35K)
    * no external dependencies within libproxy core
      (libproxy plugins may have dependencies)
    * only 3 functions in the stable external API
    * dynamic adjustment to changing network topology
    * a standard way of dealing with proxy settings across all scenarios
    * a sublime sense of joy and accomplishment 

%package -n %{libname}
Group:System/Libraries
Summary:        A library handling all the details of proxy configuration
#Virtual Provides - We need either mozjs or WebKit
%if !%{bootstrap}
Requires: %{name}-pac >= %{version}
%endif
Obsoletes:	libproxy0
%if !%{with mozjs}
Obsoletes:     %{mklibname proxy-mozjs} < %version-%release
%endif

%description -n %{libname}
libproxy offers the following features:

    * extremely small core footprint (< 35K)
    * no external dependencies within libproxy core
      (libproxy plugins may have dependencies)
    * only 3 functions in the stable external API
    * dynamic adjustment to changing network topology
    * a standard way of dealing with proxy settings across all scenarios
    * a sublime sense of joy and accomplishment 

%package        utils
Summary:        Binary to test %{name}
Group:          System/Networking
Requires:       %{libname} = %{version}-%{release}

%description    utils
The %{name}-utils package contains the proxy binary for %{name}

%package -n python3-%{name}
Summary:        Binding for %{name} and python3
Group:          Development/Python
Requires:       %{libname} = %{version}-%{release}
Obsoletes:      python-%{name}

%description -n python3-%{name}
The python3-%{name} package contains the python3 binding for %{name}.

%package        perl
Summary:        Perl bindings for %{name}
Group:          Development/Perl
Requires:       %{libname} = %{version}-%{release}

%description    perl
This contains the perl bindings for the libproxy library.

%package	gxsettings
Summary:	Helper utility for %{name} gnome support
Group:		System/Libraries

%description gxsettings
A helper utility for %{name} gnome support.

%package -n     %{gnomename}
Summary:        Plugin for %{name} and gnome
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
%if !%{bootstrap}
Requires:       %{nmname} = %{version}-%{release}
%endif
Requires:	%{name}-gxsettings = %{version}-%{release}
Obsoletes:	libproxy-gnome < %{first_biarch_version}
Requires:	gsettings-desktop-schemas

%description -n %{gnomename}
The %{name}-gnome package contains the %{name} plugin for gnome.

%package -n     %{kdename}
Summary:        Plugin for %{name} and kde
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       %{nmname} = %{version}-%{release}
# for kreadconfig5
Requires:	kconfig
Obsoletes:	libproxy-kde < %{first_biarch_version}

%description -n %{kdename}
The %{name}-kde package contains the %{name} plugin for kde.

%if !%{bootstrap}
%package -n     %{nmname}
Summary:        Plugin for %{name} and NetworkManager
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n %{nmname}
The %{name}-networkmanager package contains the %{name} plugin for NetworkManager.

%package -n     %{mozjsname}
Summary:        Plugin for %{name} and mozjs
Group:          System/Libraries
Requires:       %{libname} = %{version}
Provides:       %{name}-pac = %{version}-%{release}
Obsoletes:	libproxy-mozjs < %{first_biarch_version}

%description -n %{mozjsname}
The %{name}-mozjs package contains the %{name} plugin for mozjs.

%package -n     %{webkitname}
Summary:        Plugin for %{name} and webkit
Group:          System/Libraries
Requires:       %{libname} = %{version}
Provides:       %{name}-pac = %{version}-%{release}
Obsoletes:	libgnome-webkit < %{first_biarch_version}

%description -n %{webkitname}
The %{name}-webkit package contains the %{name} plugin for
webkit.
%endif

%package        pacrunner
Summary:        Plugin for %{name} and PacRunner
Group:          System/Libraries
Requires:       %{libname} = %{version}
Provides:       %{name}-pac = %{version}-%{release}
#Requires:       pacrunner

%description    pacrunner
The %{name}-pacrunner package contains the %{name} plugin for
PacRunner.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q
%apply_patches

%build
%if %{bootstrap}
export CC="gcc -L$(pkg-config --variable sdkdir libxul)/lib"
%endif
# (blino) do not build pacrunner as internal (BIPR=OFF), to avoid having gtk deps in the main package
%cmake \
	-DLIBEXEC_INSTALL_DIR=%{_libexecdir} \
	-DMODULE_INSTALL_DIR=%{_libdir}/%{name}/%{version}/modules \
	-DBIPR=OFF \
%if !%{with mozjs}
	-DWITH_MOZJS=OFF \
%endif
	-DPERL_VENDORINSTALL=1 \
	-DPERL_LINK_LIBPERL=1 \
	-DWITH_WEBKIT3=1 \
	-DPYTHON3_EXECUTABLE=%{__python3} \
	-DPYTHON3_SITEPKG_DIR=%{python3_sitelib}
%cmake_build

%install
%cmake_install

# Man page.
install -Dpm 0644 %{SOURCE1} %{buildroot}/%{_mandir}/man1/proxy.1

#gw fix pkgconfig file
sed -i -e "s^Version:.*^Version: %version^" %{buildroot}%{_libdir}/pkgconfig/*.pc

rm -rf %buildroot/%{python_sitelib}

%clean
rm -rf %{buildroot}

%files -n %{libname}
%doc AUTHORS README
%{_libdir}/libproxy.so.%{major}*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%dir %{_libdir}/%{name}/%{version}/modules

%files utils
%{_bindir}/proxy
%{_mandir}/man1/proxy.1*

%files -n python3-%{name}
%{python3_sitelib}/*

%files perl
%{perl_vendorarch}/Net/Libproxy.pm
%{perl_vendorarch}/auto/Net/Libproxy

%files gxsettings
%{_libexecdir}/pxgsettings
#{_prefix}/libexec/pxgsettings

%files -n %{gnomename}
%{_libdir}/%{name}/%{version}/modules/config_gnome3.so

%files -n %{kdename}
%{_libdir}/%{name}/%{version}/modules/config_kde.so

%if !%{bootstrap}
%files -n %{nmname}
%{_libdir}/%{name}/%{version}/modules/network_networkmanager.so

%if %{with mozjs}
%files -n %{mozjsname}
%{_libdir}/%{name}/%{version}/modules/pacrunner_mozjs.so
%endif

%files -n %{webkitname}
%{_libdir}/%{name}/%{version}/modules/pacrunner_webkit.so

%files pacrunner
%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
%endif

%files -n %{develname}
%{_includedir}/proxy.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libproxy-1.0.pc
%{_datadir}/cmake/Modules/Findlibproxy.cmake


%changelog
* Mon Aug 01 2022 TerryN <terryn94 at gmail.com> 0.4.17-2pclos2022
- rebuild for python 3.10

* Wed Dec 30 2020 tex - 0.4.17-1pclos2021
- new version

* Sat Oct 04 2019 tex - 0.4.15-1pclos2019
- update for new icu

* Mon Aug 19 2013 billybot <billybot> 0.4.11-1pclos2013
- update python 2.7

* Wed Aug 24 2011 Texstar <texstar at gmail.com> 0.4.7-1pclos2011
- 0.4.7

* Mon Sep 06 2010 Texstar <texstar at gmail.com> 0.3.1-5pclos2010
- rebuild

* Thu Aug 12 2010 Texstar <texstar at gmail.com> 0.3.1-4pclos2010
- rebuild

* Sat Jun 26 2010 Texstar <texstar at gmail.com> 0.3.1-3pclos2010
- rebuild
